@@ -1,7 +1,8 @@
+from .aggregates import aggregated
+from .batch import batch_fetch, with_backrefs
 from .decorators import generates
 from .exceptions import ImproperlyConfigured
 from .functions import (
-    batch_fetch,
     defer_except,
     escape_like,
     identity,
@@ -13,11 +14,14 @@ from .functions import (
     mock_engine,
     sort_query,
     table_name,
-    with_backrefs
+    database_exists,
+    create_database,
+    drop_database
 )
 from .listeners import coercion_listener
 from .merge import merge, Merger
 from .generic import generic_relationship
+from .primitives import NumberRange, NumberRangeException
 from .proxy_dict import ProxyDict, proxy_dict
 from .types import (
     ArrowType,
@@ -30,13 +34,12 @@ from .types import (
     instrumented_list,
     InstrumentedList,
     IPAddressType,
+    JSONType,
     LocaleType,
     Password,
     PasswordType,
     PhoneNumber,
     PhoneNumberType,
-    NumberRange,
-    NumberRangeException,
     NumberRangeRawType,
     NumberRangeType,
     ScalarListType,
@@ -47,10 +50,11 @@ from .types import (
 )
 
 
-__version__ = '0.20.0'
+__version__ = '0.22.0'
 
 
 __all__ = (
+    aggregated,
     batch_fetch,
     coercion_listener,
     defer_except,
@@ -80,6 +84,7 @@ __all__ = (
     ImproperlyConfigured,
     InstrumentedList,
     IPAddressType,
+    JSONType,
     LocaleType,
     Merger,
     NumberRange,
@@ -96,4 +101,7 @@ __all__ = (
     TimezoneType,
     TSVectorType,
     UUIDType,
+    database_exists,
+    create_database,
+    drop_database
 )
